@@ -1,6 +1,6 @@
 package Email::Sender;
 # ABSTRACT: a library for sending email
-$Email::Sender::VERSION = '1.300026'; # TRIAL
+$Email::Sender::VERSION = '1.300029'; # TRIAL
 use Moo::Role;
 requires 'send';
 
@@ -68,7 +68,7 @@ Email::Sender - a library for sending email
 
 =head1 VERSION
 
-version 1.300026
+version 1.300029
 
 =head1 SYNOPSIS
 
@@ -123,7 +123,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Efros Aristotle Pagaltzis Christian Walde David Golden Steinbrunner Hans Dieter Pearcey HIROSE Masaaki Justin Hunter Kenichi Ishigaki kga Kris Matthews William Blunn
+=for stopwords Alex Efros Aristotle Pagaltzis Christian Walde David Golden Steinbrunner Hans Dieter Pearcey HIROSE Masaaki Justin Hunter Karen Etheridge Kenichi Ishigaki kga Kris Matthews William Blunn
 
 =over 4
 
@@ -161,6 +161,10 @@ Justin Hunter <justin.d.hunter@gmail.com>
 
 =item *
 
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
 Kenichi Ishigaki <ishigaki@cpan.org>
 
 =item *
