@@ -1,6 +1,6 @@
 package Email::Sender::Transport::SMTP;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300026'; # TRIAL
+$Email::Sender::Transport::SMTP::VERSION = '1.300029'; # TRIAL
 use Moo;
 
 use Email::Sender::Failure::Multi;
@@ -126,8 +126,10 @@ sub _quoteaddr {
   my $domain     = pop @localparts;
   my $localpart  = join q{@}, @localparts;
 
-  # this is probably a little too paranoid
-  return $addr unless $localpart =~ /[^\w.+-]/ or $localpart =~ /^\./;
+  return $addr # The first regex here is RFC 821 "specials" excepting dot.
+    unless $localpart =~ /[\x00-\x1F\x7F<>\(\)\[\]\\,;:@"]/
+    or     $localpart =~ /^\./
+    or     $localpart =~ /\.$/;
   return join q{@}, qq("$localpart"), $domain;
 }
 
@@ -321,7 +323,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300026
+version 1.300029
 
 =head1 DESCRIPTION
 
